//////////////////////////////////////////////////////
/// The following example illustrates a Client to a 
/// COM+ component developed using C# and .NET.
/// 
/// author: Gopalan Suresh Raj
/// Copyright (c), 2001. All Rights Reserved.
/// URL: http://gsraj.tripod.com/
/// email: gopalan@gmx.net
/// 
/// <compile>
/// csc /r:Bank.dll /t:exe /out:Client.exe Client.cs
/// </compile>
/// <run>
/// Client create Checking "Athul Raj" 10000
/// Client delete 1
/// </run>
//////////////////////////////////////////////////////

using System;
// Include the AccountManager COM+ Component namespace
using Bank;
// Include the support class's BookKeeper namespace
using BookKeeper;

namespace AccountManager {
  /// <summary>
  /// Summary description for Client.
  /// </summary>
  public class Client {
    /// <summary>
    /// Entry Point to the Client Application
    /// </summary>
    /// <param name="args"></param>
    /// <returns></returns>
    public static int Main (String[] args) {
      int argLength = args.Length;
      if ( argLength < 2) {
        Console.WriteLine ("Usage: Client <0:create|delete> [1:accountNumber|Checking|Savings] [2:customerName] [3:startingBalance]");
        return -1;
      }

      string operation = "", type = "";
      string []customerNames = new String [1];
      int accountNumber = 0;
      float startingBalance = 0;

      AccountKey key = new AccountKey ();

      try {
        // Create the COM+ component
        Bank.AccountManager manager = new Bank.AccountManager ();
        Console.WriteLine ("Obtained a reference to the Server Object...");

        operation = args [0];

        if (argLength > 2) {
          type = args [1];
          // This can be a create operation
          if (operation.Trim().ToLower() == "create") {
            if (type.Trim().ToLower() == "checking") {
              key.Type = AccountType.CheckingAccount;       
            }
            if (type.Trim().ToLower() == "savings") {
              key.Type = AccountType.SavingsAccount;
            }
            customerNames[0] = args[2];
            startingBalance = (float)System.Double.Parse (args[3]);
            Console.WriteLine ("Invoking createAccount() now ...");
            // Invoke operations on the COM+ component
            int accountKey = manager.create (key.Type, customerNames, startingBalance);
            Console.WriteLine ("Key of new Row is: {0}", accountKey);
          }
        }
        else {
          // This can be a delete operation
          if (operation.Trim().ToLower() == "delete") {
            accountNumber = System.Int32.Parse (args[1]);
            Console.WriteLine ("Invoking deleteAccount() now ...");
            bool result = false;
            // Invoke operations on the COM+ component
            result = manager.delete (accountNumber);
            if (result == true) {
              Console.WriteLine ("deleteAccount() succeeded...");
            }
            else {
              Console.WriteLine ("deleteAccount() Failed !!!");
            }
          }
        }
      }
      catch (Exception exception) {
        Console.WriteLine (exception.ToString());
      }

      return 0;
    }
  }
}
