//////////////////////////////////////////////////////
/// The following example illustrates a Client to a 
/// Distributed component developed using C# and .NET.
/// 
/// author: Gopalan Suresh Raj
/// Copyright (c), 2001. All Rights Reserved.
/// URL: http://gsraj.tripod.com/
/// email: gopalan@gmx.net
/// 
/// <compile>
/// csc /r:BookKeeper.exe KeeperClient.cs
/// </compile>
/// <run>
/// KeeperClient create Checking "Athul Raj" 10000
/// KeeperClient delete 1
/// </run>
///////////////////////////////////////////////////////// Compile with:
using System;
// Include Remoting API functionality
using System.Runtime.Remoting;
using System.Runtime.Remoting.Channels;
using System.Runtime.Remoting.Channels.Tcp;

namespace BookKeeper {
  /// <summary>
  /// The KeeperClient class.
  /// </summary>
  public class KeeperClient {

    /// <summary>
    /// Static Entry Point to the Application
    /// </summary>
    /// <param name="args"></param>
    /// <returns></returns>
    public static int Main (String[] args) {
      int argLength = args.Length;
      if ( argLength < 2) {
        Console.WriteLine ("Usage: KeeperClient <create|delete> <accountNumber|Checking|Savings> <customerName> <startingBalance>");
        return -1;
      }

      string operation = "", type = "";
      string []customerNames = new String [1];
      int accountNumber = 0;
      float startingBalance = 0;

      AccountKey key = new AccountKey ();

      try {
        // Get a reference to the remote Distributed Component
        TcpChannel channel = new TcpChannel ();
        ChannelServices.RegisterChannel (channel);
        BookKeeper keeper = (BookKeeper) Activator.GetObject (typeof( BookKeeper ),
                                                              "tcp://127.0.0.1:4000/BookKeeper");
        Console.WriteLine ("Obtained a reference to the Server Object...");

        operation = args [0];

        if (argLength > 2) {
          type = args [1];
          // This can be a create operation
          if (operation.Trim().ToLower() == "create") {
            if (type.Trim().ToLower() == "checking") {
              key.Type = AccountType.CheckingAccount;       
            }
            if (type.Trim().ToLower() == "savings") {
              key.Type = AccountType.SavingsAccount;
            }
            customerNames[0] = args[2];
            startingBalance = (float)System.Double.Parse (args[3]);
            Console.WriteLine ("Invoking createAccount() now ...");
            // Invoke operations on the Distributed Component
            key = keeper.createAccount (key.Type, customerNames, startingBalance);
            Console.WriteLine ("Key of new Row is: {0}", key.Key);
          }
        }
        else {
          // This can be a delete operation
          if (operation.Trim().ToLower() == "delete") {
            accountNumber = System.Int32.Parse (args[1]);
            key.Key = accountNumber;
            Console.WriteLine ("Invoking deleteAccount() now ...");
            // Invoke operations on the Distributed Component
            bool result = keeper.deleteAccount (key);
          }
        }
        // Dispose of the object
        keeper = null;
      }
      catch (Exception exception) {
        Console.WriteLine (exception.ToString());
      }
      return 0;
    }
  }
}
