using System;
using System.Messaging;
using System.Threading;

namespace Queue {
  /// <summary>
  /// Summary description for QueueClient.
  /// </summary>
  public class QueueClient {
    public QueueClient() {
    }

    public static void Main (String[] args) {
	 
      // Get the name of this Message Sender application
      string applicationName = Environment.GetCommandLineArgs ()[0];
      // Test that the number of arguments passed in are ok
      if (args.Length != 1) {
        Console.WriteLine ("Usage: "+
          applicationName+
          " <Queue Name>");
        return;
      }
	  
      string messageQueuePath = ".\\"+args [0];
      // If such a Message Queue does not exist
      if (MessageQueue.Exists (messageQueuePath) == false) {
        // Give out an Error Message to that effect and Exit
        Console.WriteLine ("The Specified Queue "+
          messageQueuePath+
          " does not exist...");
        return;                   
      } 
      // Create a MessageQueue Object for that Queue
      MessageQueue messageQueue = new MessageQueue (messageQueuePath);
      // Setup a Message Handler for this Queue
      messageQueue.AddOnReceiveCompleted (new ReceiveCompletedEventHandler (Arrived));
      // Start looking for messages
      messageQueue.BeginReceive ();
	  
      // Block and stay alive on the Console
      Console.WriteLine ("Press enter to stop the program...");
      Console.ReadLine ();
    } // end main
	 
    // The Message Handler for receiveing Messages Asynchronously
    public static void Arrived (Object source, ReceiveAsyncEventArgs asyncReceive) {
	 
      // Get a handle to the Message Queue
      MessageQueue messageQueue = (MessageQueue) source;
      // Start Receiving Messages
      Message message = messageQueue.EndReceive (asyncReceive.AsyncResult);
      // Display the Received Message
      Console.WriteLine ("The Message Received Reads :" + (string)message.Body);
      // Start Looking for Messages again
      messageQueue.BeginReceive ();
    } // end Arrived

  }
}
