//////////////////////////////////////////////////////
/// The following example shows a Distributed Component
/// Client developed using C# and the .NET Framework.
/// 
/// author: Gopalan Suresh Raj
/// Copyright (c), 2002. All Rights Reserved.
/// URL: http://gsraj.tripod.com/
/// email: gopalan@gmx.net
/// 
/// <compile>
/// csc /r:TopicServer.exe TopicClient.cs
/// </compile>
/// <usage>
/// TopicClient port
/// </usage>
//////////////////////////////////////////////////////
using System;
// Import the Remoting API support
using System.Runtime.Remoting;
using System.Runtime.Remoting.Channels;
using System.Runtime.Remoting.Channels.Http;
// Use the Topic namespace
using Topic;

namespace Topic {
  /// <summary>
  /// The Client to a Distributed Bulletin Board Server
  /// </summary>
  class TopicClient {
    static void Main(string[] args) {

      if (args.Length < 1) {
        Console.WriteLine( "\tUsage: TopicClient port" );
        Console.WriteLine( "\t e.g., TopicClient 1000" ); 
        return;
      }

      int listeningChannel = Int32.Parse( args [0] );
      // Create and register a channel to communicate to the server
      // The Client will use the port passed in as args to listen for callbacks
      HttpChannel channel = new HttpChannel( listeningChannel );
      ChannelServices.RegisterChannel( channel );

      // Create an instance on the remote server and call a method remotely
      Topic topic = (Topic) Activator.GetObject( typeof ( Topic ),             // type to create
                                                 "http://localhost:1099/Topic" // URI
                                                );
      if (topic == null) {
        Console.WriteLine( "Unable to obtain a Reference to the Remote Topic Server component ..." );
        return;
      }
      // Create a unique Client ID
      string clientID = Guid.NewGuid().ToString();
      string message = "New Client ID: "+clientID+", Connected From Port "+listeningChannel;
      // Invoke a method from the Server and display the returned value
      Console.WriteLine( topic.displayMessage( clientID, message ) );
      while (message.ToLower().StartsWith( "quit" ) == false) {
        Console.WriteLine( "Enter a Message to Add to Server, 'quit' to exit application" );
        message = Console.ReadLine();
        topic.addMessage( clientID, message );
      }
      Console.WriteLine( "The Messages Are:" + topic.retrieveAllMessages( clientID ) );
      topic.displayMessage( clientID, 
                            "Client "+ clientID +
                            ": Connected From Port "+listeningChannel+
                            ", Terminating..." );
    }

  }
}
